#ifndef UTILITIES_NEWTYPES_NEWTYPES_H
#define UTILITIES_NEWTYPES_NEWTYPES_H

// Modifiers
#include "External.h"

// Types
#include "Array.h"
#include "Vector.h"
#include "Matrix.h"

// Cast
#include "ArrayCast.h"

// Global functions
#include "Globals.h"

#endif
